@@ -495,10 +495,7 @@ int powernet_snmp_ups_check_state(UPSINFO *ups)
    if (rc == 0)
       return 0;
 
-   /* Allow user to reduce sleep_time using NETTIME config setting */
    sleep_time = ups->wait_time;
-   if (ups->nettime && ups->nettime < ups->wait_time)
-      sleep_time = ups->nettime;
 
    /* If we're not doing SNMP traps, just sleep and exit */
    if (!Sid->trap_session) {
@@ -583,8 +580,8 @@ int powernet_snmp_ups_open(UPSINFO *ups)
 
    /* Trap session is a copy of client session with some tweaks */
    tmp = *s;
-   tmp.peername = "0.0.0.0:162";   /* Listen to snmptrap port on all interfaces */
-   tmp.local_port = 1;             /* We're a server, not a client */
+   tmp.peername = (char*)"0.0.0.0:162";  /* Listen to snmptrap port on all interfaces */
+   tmp.local_port = 1;                   /* We're a server, not a client */
    tmp.callback = powernet_snmp_callback;
    tmp.callback_magic = my_data;
 
