@@ -26,6 +26,7 @@
 #include "../usb_common.h"
 #include "hidutils.h"
 #include "libusb.h"
+#include "astring.h"
 
 /*
  * When we are traversing the USB reports given by the UPS and we find
@@ -53,15 +54,13 @@ typedef struct s_usb_info {
  */
 typedef struct s_usb_data {
    usb_dev_handle *fd;             /* Our UPS control pipe fd when open */
-   char orig_device[MAXSTRING];    /* Original port specification */
-   short vendor;                   /* UPS vendor id */
    report_desc_t rdesc;            /* Device's report descrptor */
    USB_INFO *info[CI_MAXCI + 1];   /* Info pointers for each command */
 } USB_DATA;
 
 int pusb_ups_get_capabilities(UPSINFO *ups, const struct s_known_info *known_info)
 {
-   int i, input, feature, ci, phys;
+   int i, input, feature, ci, phys, logi;
    USB_DATA *my_data = (USB_DATA *)ups->driver_internal_data;
    hid_item_t item, witem;
    USB_INFO *info;
@@ -71,6 +70,7 @@ int pusb_ups_get_capabilities(UPSINFO *ups, const struct s_known_info *known_inf
    for (i = 0; known_info[i].usage_code; i++) {
       ci = known_info[i].ci;
       phys = known_info[i].physical;
+      logi = known_info[i].logical;
 
       if (ci != CI_NONE && !my_data->info[ci]) {
          /* Try to find an INPUT report containing this usage */
@@ -79,7 +79,7 @@ int pusb_ups_get_capabilities(UPSINFO *ups, const struct s_known_info *known_inf
             known_info[i].usage_code,     /* Match usage code */
             -1,                           /* Don't care about application */
             (phys == P_ANY) ? -1 : phys,  /* Match physical usage */
-            -1,                           /* Don't care about logical */
+            (logi == P_ANY) ? -1 : logi,  /* Match logical usage */
             HID_KIND_INPUT,               /* Match feature type */
             &item);
 
@@ -89,7 +89,7 @@ int pusb_ups_get_capabilities(UPSINFO *ups, const struct s_known_info *known_inf
                known_info[i].usage_code,     /* Match usage code */
                -1,                           /* Don't care about application */
                (phys == P_ANY) ? -1 : phys,  /* Match physical usage */
-               -1,                           /* Don't care about logical */
+               (logi == P_ANY) ? -1 : logi,  /* Match logical usage */
                HID_KIND_FEATURE,             /* Match feature type */
                &witem);
 
@@ -110,7 +110,7 @@ int pusb_ups_get_capabilities(UPSINFO *ups, const struct s_known_info *known_inf
          info = (USB_INFO *)malloc(sizeof(USB_INFO));
          if (!info) {
             write_unlock(ups);
-            Error_abort0(_("Out of memory.\n"));
+            Error_abort0("Out of memory.\n");
          }
 
          // Use INPUT report as the main readable report
@@ -329,12 +329,38 @@ int init_device(UPSINFO *ups, struct usb_device *dev)
 #ifdef LIBUSB_HAS_DETACH_KERNEL_DRIVER_NP
    /*
     * Attempt to detach the kernel driver so we can drive
-    * this device from userspace.
+    * this device from userspace. Don't worry if this fails;
+    * that just means the driver was already detached.
     */
    rc = usb_detach_kernel_driver_np(fd, 0);
-   Dmsg1(200, "Kernel detach returned %d\n", rc);
 #endif
 
+   /* Check device serial number, if user specified one */
+   if (ups->device[0] != '\0')
+   {
+      /* Fetch serial number from device */
+      const char *tmpser;
+      if (dev->descriptor.iSerialNumber == 0 ||
+          (tmpser = hidu_get_string(fd, dev->descriptor.iSerialNumber)) == NULL)
+      {
+         usb_close(fd);
+         Dmsg0(100, "Device does not report serial number.\n");
+         return 0;
+      }
+
+      /* Remove leading/trailing whitespace */
+      astring serial(tmpser);
+      serial.trim();
+
+      /* Check against user specification, ignoring case */
+      Dmsg2(100, "device='%s', user='%s'\n", serial.str(), ups->device);
+      if (strcasecmp(serial, ups->device))
+      {
+         usb_close(fd);
+         return 0;
+      }
+   }
+
    /* Choose config #1 */
    rc = usb_set_configuration(fd, 1);
    if (rc) {
@@ -383,7 +409,6 @@ int init_device(UPSINFO *ups, struct usb_device *dev)
       return 0;
    }
 
-   my_data->vendor = dev->descriptor.idVendor;
    my_data->fd = fd;
    return 1;
 }
@@ -419,9 +444,6 @@ int open_usb_device(UPSINFO *ups)
             Dmsg2(200, "Trying device %s:%s\n", bus->dirname, dev->filename);
             if (init_device(ups, dev)) {
                /* Successfully found and initialized an UPS */
-               astrncpy(ups->device, bus->dirname, sizeof(ups->device));
-               astrncat(ups->device, ":", sizeof(ups->device));
-               astrncat(ups->device, dev->filename, sizeof(ups->device));
                return 1;
             }
          }
@@ -433,7 +455,6 @@ int open_usb_device(UPSINFO *ups)
    }
 
    /* Failed to find an UPS */
-   ups->device[0] = 0;
    return 0;
 }
 
@@ -626,14 +647,11 @@ int pusb_ups_open(UPSINFO *ups)
       reinitialize_private_structure(ups);
    }
 
-   if (my_data->orig_device[0] == 0)
-      astrncpy(my_data->orig_device, ups->device, sizeof(my_data->orig_device));
-
    if (!open_usb_device(ups)) {
       write_unlock(ups);
-      Error_abort0(_("Cannot find UPS device --\n"
+      Error_abort0("Cannot find UPS device --\n"
             "For a link to detailed USB trouble shooting information,\n"
-            "please see <http://www.apcupsd.com/support.html>.\n"));
+            "please see <http://www.apcupsd.com/support.html>.\n");
    }
 
    /*
