@@ -47,14 +47,14 @@ private:
       std::string text;
    };
 
-   std::vector<Balloon> m_pending;
-   HANDLE               m_mutex;
-   bool                 m_active;
-   HANDLE               m_event;
-   HANDLE               m_timer;
-   bool                 m_exit;
-   struct timeval       m_time;
-   HANDLE               m_thread;
+   std::vector<Balloon> _pending;
+   HANDLE               _mutex;
+   bool                 _active;
+   HANDLE               _event;
+   HANDLE               _timer;
+   bool                 _exit;
+   struct timeval       _time;
+   HANDLE               _thread;
 };
 
 #endif // BALLOONMGR_H
